import QtQuick 2.0
import "components"
import com.reachtech.systemplugin 1.0
import QtMultimedia 5.0

Rectangle {
    id: page
    width: 800
    height: 480

    property int freqScale: 10

    // manually-added elements to access the Backlight and Beeper
    Backlight {
        id: backlight
    }

    SoundEffect{
        id: beeper
        source: "beep.wav"
        volume: 0.7
    }

    // manually-added elements to access the IP address and 'system' features
    Network {
      id: network
    }

    System {
      id: system
    }
    // end manually-added elements


    HorizontalSlider {
        id: slider___brightness1
        x: 295
        y: 177
        width: 211
        height: 48
        hintBorderColor: "#000000"
        showHint: true
        maximum: 7
        hintBorderWidth: 2
        hintFontFamily: "Arial"
        hintBackgroundColor: "#ffffff"
        hintFontColor: "#000000"
        hintFontPixelSize: 16
        imageTrack: "images/slider_htrack.png"
        minimum: 5
        xMin: 0
        value: 5
        handleY: 2
        imageOverlay: ""
        hintRadius: 9
        hintWidth: 40
        imageHandle: "images/slider_handle.png"
        allowDrag: true
        hintHeight: 40

        // slider immediately adjusts backlight brightness
        onValueChanged: {
            backlight.setBrightness(slider___brightness1.value);
            backlightBrightnessValue.text = qsTr("%1".arg(slider___brightness1.value));
        }
    }

    Text {
        id: text1
        x: 295
        y: 231
        text: qsTr("Backlight Brightness:")
        font.family: "DejaVu Sans"
        font.pixelSize: 16
    }

    Text {
        id: backlightBrightnessValue
        x: 475
        y: 231
        text: qsTr("000")
        font.pixelSize: 16
        font.family: "DejaVu Sans"
    }

    ImageButton {
        id: buttonBeep
        x: 252
        y: 81
        width: 60
        height: 40
        text: "Beep"
        imageUp: "images/internal_button_up.bmp"
        font.pixelSize: 18
        textColor: "#000000"
        imageDown: "images/internal_button_dn.bmp"
        font.bold: false
        font.family: "DejaVu Sans"

        onButtonPress: {
            beeper.play();
        }
    }

    HorizontalSlider {
        id: slider___volume1
        x: 331
        y: 77
        width: 183
        height: 48
        hintBorderColor: "#000000"
        showHint: true
        maximum: 10
        hintBorderWidth: 2
        hintFontFamily: "Arial"
        hintBackgroundColor: "#ffffff"
        hintFontColor: "#000000"
        hintFontPixelSize: 16
        imageTrack: "images/slider_htrack.png"
        minimum: 0
        xMin: 0
        value: 3
        handleY: 2
        imageOverlay: ""
        hintRadius: 9
        hintWidth: 40
        imageHandle: "images/slider_handle.png"
        allowDrag: true
        hintHeight: 40

        // slider immediately adjusts beeper volume
        onValueChanged: {
            beeper.volume = value / 10;
            beepVolumeValue.text = qsTr("%1".arg(slider___volume1.value));
        }
    }

    Text {
        id: text2
        x: 346
        y: 131
        text: qsTr("Beep Volume:")
        font.family: "DejaVu Sans"
        font.pixelSize: 16
    }

    Text {
        id: beepVolumeValue
        x: 466
        y: 131
        text: qsTr("000")
        font.family: "DejaVu Sans"
        font.pixelSize: 16
    }

    Text {
        id: text5
        x: 274
        y: 277
        width: 66
        height: 15
        text: qsTr("IP Address:")
        font.family: "DejaVu Sans"
        font.pixelSize: 16
    }

    Text {
        id: ip_address
        x: 375
        y: 277
        width: 146
        height: 15
        text: qsTr("111.222.333.444")
        font.family: "DejaVu Sans"
        font.pixelSize: 16
    }

    Text {
        id: system_date_time
        x: 274
        y: 353
        width: 183
        height: 15
        text: qsTr("HH:MM:SS, January 1, 1970")
        font.family: "DejaVu Sans"
        font.pixelSize: 16
        horizontalAlignment: Text.AlignLeft
    }

    Component.onCompleted: {
        // display current date and time
        // format as per http://qt-project.org/doc/qt-4.8/qml-qt.html#formatDateTime-method
        system_date_time.text = Qt.formatDateTime(system.currentDateTime(), "hh:mm:ss, MMMM dd, yyyy")
        // display current IP address
        ip_address.text = qsTr("%1").arg(network.getIp());
        // at startup, pre-set sliders and text fields to current hardware settings
        slider___brightness1.value = backlight.brightness();
            backlightBrightnessValue.text = qsTr("%1".arg(backlight.brightness()));
        slider___volume1.value = beeper.volume * 10;
            beepVolumeValue.text = qsTr("%1".arg(beeper.volume()));
    }

}

